@@ -102,7 +102,7 @@ define!({
         DashedIdent(DashedIdent),
         Str(Str),
         Function(Function),
-        Bin(BinValue),
+        CalcSum(CalcSum),
         Delimiter(Delimiter),
         Urange(Urange),
         Url(Url),
@@ -120,16 +120,6 @@ define!({
         pub value: DelimiterValue,
     }
 
-    pub struct BinValue {
-        pub span: Span,
-
-        pub op: BinOp,
-
-        pub left: Box<Value>,
-
-        pub right: Box<Value>,
-    }
-
     pub struct Function {
         pub span: Span,
         pub name: Ident,
@@ -239,6 +229,47 @@ define!({
         pub value: JsWord,
     }
 
+    pub struct CalcSum {
+        pub span: Span,
+        pub expressions: Vec<CalcProductOrOperator>,
+    }
+
+    pub enum CalcProductOrOperator {
+        Product(CalcProduct),
+        Operator(CalcOperator),
+    }
+
+    pub struct CalcProduct {
+        pub span: Span,
+        pub expressions: Vec<CalcValueOrOperator>,
+    }
+
+    pub struct CalcOperator {
+        pub span: Span,
+        pub value: CalcOperatorType,
+    }
+
+    pub enum CalcOperatorType {
+        Add,
+        Sub,
+        Mul,
+        Div,
+    }
+
+    pub enum CalcValueOrOperator {
+        Value(CalcValue),
+        Operator(CalcOperator),
+    }
+
+    pub enum CalcValue {
+        Number(Number),
+        Dimension(Dimension),
+        Percentage(Percentage),
+        Constant(Ident),
+        Sum(CalcSum),
+        Function(Function),
+    }
+
     pub struct SelectorList {
         pub span: Span,
         pub children: Vec<ComplexSelector>,
